@@ -63,4 +63,4 @@ def author():
 	print('This module is written by Dr.Wu. Please enjoy.')
 
 if __name__ == '__main__':
-	make_certificate('Dr.Wu','Best Teacher.')
\ No newline at end of file
+	make_certificate('正正','学习积极分子')
\ No newline at end of file
